/**
This example displays an array of keys that can be touched to update the display
like a keypad.
*/

#include "io430.h"
#include "stdint.h"
#include "GUD_I2C_Interface.h"
#include "GUD_SPI_Interface.h"
#include "GUD_UART_Interface.h"
#include "GUD900.h"

int main ( void )
{
  int status;
  int touch = 0;
  uint8_t data;
  initSPI();
  beginWriteSPI();
  GUD_init(128, 32);
  
  //Write the graphical interface button to FROM.
  GUD_enterUserSetupMode();
  GUD_FROMImageDefinition(0x00, 0x00, 0x00, 128, 0x00, GU_Button);
  GUD_endUserSetupMode();
  endSPI();
  int valid2 = 0;
  // Read and disregard user mode data.
  status = readSPIStatus();
    if(status > 0 && status <= 63){
      startSPIRead();
      for(int i = 0; i < status + 1; i++){
        data = singleSPIRead();
        if(valid2){
          RxDataArray[i] = data;
        }
        if(data == 0x28 && valid2 == 0){
          i = 0;
          RxDataArray[i] = data;
          valid2 = 1;
        }
      }
    }
  valid2 = 0;
  endSPI();
  
  // Draw the stored graphical interface button to the display a few times.
  beginWriteSPI();
  GUD_drawFROMImage(224, 0, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(192, 0, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(160, 0, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(224, 32, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(192, 32, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(160, 32, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(224, 64, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(192, 64, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(160, 64, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(224, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(192, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(160, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  
  GUD_drawFROMImage(0, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(32, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(64, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(96, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  GUD_drawFROMImage(128, 96, 0x01, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 32, 32);
  
  //Add labels to the buttons.
  GUD_setFontSize(1, 1, 1);
  GUD_printDotUnitChar(172, 8, "1", 1);
  GUD_printDotUnitChar(204, 8, "2", 1);
  GUD_printDotUnitChar(236, 8, "3", 1);
  
  GUD_printDotUnitChar(172, 40, "4", 1);
  GUD_printDotUnitChar(204, 40, "5", 1);
  GUD_printDotUnitChar(236, 40, "6", 1);
  
  GUD_printDotUnitChar(172, 72, "7", 1);
  GUD_printDotUnitChar(204, 72, "8", 1);
  GUD_printDotUnitChar(236, 72, "9", 1);
  
  GUD_printDotUnitChar(169, 104, "En", 2);
  GUD_printDotUnitChar(204, 104, "0", 1);
  GUD_printDotUnitChar(228, 104, "Clr", 3);
  
  GUD_printDotUnitChar(12, 104, "A", 1);
  GUD_printDotUnitChar(44, 104, "B", 1);
  GUD_printDotUnitChar(76, 104, "C", 1);
  GUD_printDotUnitChar(108, 104, "D", 1);
  GUD_printDotUnitChar(140, 104, "E", 1);
  
  //Create a custom user window for text display.
  GUD_defineWindow(1, 0, 0, 160, 96);
  GUD_selectWindow(1);
  GUD_setFontSize(2, 2, 1);
  GUD_touchSet(0x02);
  
  endSPI();
  
  //Read in touch values and display that button's number in the user window.
  while(1){
    int valid = 0;
    status = readSPIStatus();
    //Make sure the status data is in the valid range
    if(status > 0 && status <= 63){
      startSPIRead();
      for(int i = 0; i < status + 1; i++){
        data = singleSPIRead();
        //if the first stored byte is valid touch data, then store data afterwards
        if(valid){
          RxDataArray[i] = data;
        }
        //Check for 0x11 to start storing touch data
        if(data == 0x11 && valid == 0){ 
          i = 0;
          RxDataArray[i] = data;
          valid = 1;
        }
      }
      valid = 0;
      endSPI();

      if(RxDataArray[0] == 0x11 && RxDataArray[2] == 0x01){
        switch(RxDataArray[1]){
        case 5:
          beginWriteSPI();
          GUD_print('1');
          endSPI();
          break;
        case 6:
          beginWriteSPI();
          GUD_print('2');
          endSPI();
          break;
        case 7:
          beginWriteSPI();
          GUD_print('3');
          endSPI();
          break;
        case 13:
          beginWriteSPI();
          GUD_print('4');
          endSPI();
          break;
        case 14:
          beginWriteSPI();
          GUD_print('5');
          endSPI();
          break;
        case 15:
          beginWriteSPI();
          GUD_print('6');
          endSPI();
          break;
        case 21:
          beginWriteSPI();
          GUD_print('7');
          endSPI();
          break;
        case 22:
          beginWriteSPI();
          GUD_print('8');
          endSPI();
          break;
        case 23:
          beginWriteSPI();
          GUD_print('9');
          endSPI();
          break;
        case 24:
          beginWriteSPI();
          GUD_print('A');
          endSPI();
          break;
        case 25:
          beginWriteSPI();
          GUD_print('B');
          endSPI();
          break;
        case 26:
          beginWriteSPI();
          GUD_print('C');
          endSPI();
          break;
        case 27:
          beginWriteSPI();
          GUD_print('D');
          endSPI();
          break;
        case 28:
          beginWriteSPI();
          GUD_print('E');
          endSPI();
          break;
        case 29:
          beginWriteSPI();
          GUD_crlf();
          endSPI();
          break;
        case 30:
          beginWriteSPI();
          GUD_print('0');
          endSPI();
          break;
        case 31:
          beginWriteSPI();
          GUD_clearScreen();
          endSPI();
          break;
        default:
          break;
        
        }
      }
	}
  }
  return 0;
}